package intellij.test;

import java.io.File;
import org.apache.maven.AbstractMavenLifecycleParticipant;
import org.apache.maven.MavenExecutionException;
import org.apache.maven.execution.MavenSession;
import org.apache.maven.model.Build;
import org.apache.maven.model.Model;
import org.apache.maven.project.MavenProject;
import org.codehaus.plexus.component.annotations.Component;
import org.sonatype.aether.RepositorySystemSession;
import org.sonatype.aether.repository.WorkspaceReader;
import org.sonatype.aether.util.artifact.DefaultArtifact;

@Component(role = AbstractMavenLifecycleParticipant.class, hint = "test-extension")
public class MyMavenExtension extends AbstractMavenLifecycleParticipant {
  @Override public void afterProjectsRead(MavenSession session) throws MavenExecutionException {
    for (MavenProject mavenProject : session.getProjects()) {
      Model model = mavenProject.getModel();
      String description = model.getDescription();
      if (description != null && description.contains("throw")) {
        throw new RuntimeException(description);
      }

      Build build = model.getBuild();
      build.setFinalName(
          "Name for " + mavenProject.getGroupId() + ":" + mavenProject.getArtifactId()
              + " generated by MyMavenExtension.");

      RepositorySystemSession repositorySession = session.getRepositorySession();
      WorkspaceReader workspaceReader = repositorySession.getWorkspaceReader();
      if (workspaceReader == null) {
        model.addProperty("workspace-info", "no WorkspaceReader");
      } else {
        File project = workspaceReader.findArtifact(new DefaultArtifact("test:project:1"));
        model.addProperty("workspace-info", project == null ? "not present" : project.getPath());
      }
    }
  }
}
